"""
    EMIL AccountingService

    The EMIL AccountingService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.accounting
from eis.accounting.api.number_ranges_api import NumberRangesApi  # noqa: E501


class TestNumberRangesApi(unittest.TestCase):
    """NumberRangesApi unit test stubs"""

    def setUp(self):
        self.api = NumberRangesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_number_range(self):
        """Test case for create_number_range

        Create the Number Range  # noqa: E501
        """
        pass

    def test_delete_number_range(self):
        """Test case for delete_number_range

        Delete the Personal Account  # noqa: E501
        """
        pass

    def test_get_number_range(self):
        """Test case for get_number_range

        Retrieve the Financial Account  # noqa: E501
        """
        pass

    def test_list_number_ranges(self):
        """Test case for list_number_ranges

        List Financial Accounts  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
