"""
    EMIL AccountingService

    The EMIL AccountingService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.accounting
from eis.accounting.api.booking_entries_api import BookingEntriesApi  # noqa: E501


class TestBookingEntriesApi(unittest.TestCase):
    """BookingEntriesApi unit test stubs"""

    def setUp(self):
        self.api = BookingEntriesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_booking_entry(self):
        """Test case for create_booking_entry

        Create the booking entry  # noqa: E501
        """
        pass

    def test_get_booking_entry(self):
        """Test case for get_booking_entry

        Retrieve the booking entry  # noqa: E501
        """
        pass

    def test_list_booking_entries(self):
        """Test case for list_booking_entries

        List booking entries  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
